package pl.fulmanski.android.tutorial.project_03;

import android.app.Notification;
import android.app.NotificationManager;
import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.support.v4.app.NotificationCompat;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.view.Gravity;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.RemoteViews;
import android.widget.TextView;
import android.widget.Toast;

public class MainActivity extends AppCompatActivity {
    int basicNotificationCounter;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        basicNotificationCounter = 0;
    }

    public void makeBasicNotification(View view){
        //Create Notification using NotificationCompat.Builder
        NotificationCompat.Builder builder = new NotificationCompat.Builder(this)
                .setSmallIcon(R.drawable.ic_my_notofication_icon)
                .setTicker("BN")
                .setContentTitle("Basic notification title")
                .setContentText(String.format("Basic notification content text. Counter = %d", basicNotificationCounter))
                .setAutoCancel(true);

        // Create Notification Manager
        NotificationManager notificationManager = (NotificationManager) getSystemService(NOTIFICATION_SERVICE);
        // Build Notification with Notification Manager
        int thisNotificationId = 0;
        notificationManager.notify(thisNotificationId, builder.build());

        basicNotificationCounter++;
    }

    public void makeInboxStyleNotification(View view){
        long currentTimeMillis = System.currentTimeMillis();

        // Add Big View Specific Configuration
        NotificationCompat.InboxStyle inboxStyle = new NotificationCompat.InboxStyle();

        String[] eventsDetails = new String[2]; // max 6 lines
        eventsDetails[0] = new String("Line number 1");
        eventsDetails[1] = new String("Line number 2");

        // Sets a title for the Inbox style big view
        inboxStyle.setBigContentTitle("Inbox big content title");

        // Moves events into the big view
        for (int i=0; i < eventsDetails.length; i++) {
            inboxStyle.addLine(eventsDetails[i]);
        }

        //Create Notification using NotificationCompat.Builder
        NotificationCompat.Builder builder = new NotificationCompat.Builder(this)
                .setSmallIcon(R.drawable.ic_my_notofication_icon)
                .setTicker("IN")
                .setContentTitle("Inbox  notification title")
                .setContentText("Inbox notification content text")
                .setStyle(inboxStyle)
                .setAutoCancel(true);

        // Create Notification Manager
        NotificationManager notificationManager = (NotificationManager) getSystemService(NOTIFICATION_SERVICE);
        // Build Notification with Notification Manager
        int thisNotificationId = 1;
        notificationManager.notify(thisNotificationId, builder.build());
    }

    public void makeBigTextStyleNotification(View view){
        String longText = "Long, very long text.";

        NotificationCompat.BigTextStyle bigTextStyle = new NotificationCompat.BigTextStyle().bigText(longText);
        // Sets a title for the Inbox style big view
        bigTextStyle.setBigContentTitle("Big text big content title");
        bigTextStyle.setSummaryText("Big summary");

        //Create Notification using NotificationCompat.Builder
        NotificationCompat.Builder builder = new NotificationCompat.Builder(this)
                .setSmallIcon(R.drawable.ic_my_notofication_icon)
                .setTicker("BTN")
                .setContentTitle("Big text  notification title")
                .setContentText("Big text notification content text")
                .setStyle(bigTextStyle)
                .setAutoCancel(true);

        // Create Notification Manager
        NotificationManager notificationManager = (NotificationManager) getSystemService(NOTIFICATION_SERVICE);
        // Build Notification with Notification Manager
        int thisNotificationId = 2;
        notificationManager.notify(thisNotificationId, builder.build());
    }

    public void makeBigPictureStyleNotification(View view){
        Bitmap bitmap_image = BitmapFactory.decodeResource(this.getResources(), R.drawable.fotka04);
        NotificationCompat.BigPictureStyle bigPictureStyle = new NotificationCompat.BigPictureStyle().bigPicture(bitmap_image);
        bigPictureStyle.setSummaryText("Summary text appears on expanding the notification");

        // Sets a title for the Inbox style big view
        bigPictureStyle.setBigContentTitle("Big text big content title");

        //Create Notification using NotificationCompat.Builder
        NotificationCompat.Builder builder = new NotificationCompat.Builder(this)
                .setSmallIcon(R.drawable.ic_my_notofication_icon)
                .setTicker("BTN")
                .setContentTitle("Big text  notification title")
                .setContentText("Big text notification content text")
                .setStyle(bigPictureStyle)
                .setAutoCancel(true);

        // Create Notification Manager
        NotificationManager notificationManager = (NotificationManager) getSystemService(NOTIFICATION_SERVICE);
        // Build Notification with Notification Manager
        int thisNotificationId = 3;
        notificationManager.notify(thisNotificationId, builder.build());
    }

    public void makeCustomNotification(View view){
        RemoteViews remoteViews = new RemoteViews(getPackageName(),
                R.layout.custom_notification);

        remoteViews.setImageViewResource(R.id.image, R.mipmap.ic_ja7);
        remoteViews.setTextViewText(R.id.title, "Custom notification title");
        remoteViews.setTextViewText(R.id.text, "Custom notification text");

        NotificationCompat.Builder builder = new NotificationCompat.Builder(this)
                .setSmallIcon(R.mipmap.ic_ja7)
                .setTicker("CN")
                .setAutoCancel(true)
                .setContent(remoteViews);

        NotificationManager notificationmanager = (NotificationManager) getSystemService(NOTIFICATION_SERVICE);
        notificationmanager.notify(4, builder.build());
    }

    public void makeToast(View view){
        Context context = getApplicationContext();
        CharSequence text = "Simple toast message";
        int duration = Toast.LENGTH_SHORT;

        Toast toast = Toast.makeText(context, text, duration);
        toast.show();
    }

    public void makeCustomToast(View view){
        LayoutInflater inflater = getLayoutInflater();
        View layout = inflater.inflate(R.layout.toast_layout,
                (ViewGroup) findViewById(R.id.toast_layout));

        TextView text = (TextView) layout.findViewById(R.id.text);
        text.setText("This is a custom toast");

        Toast toast = new Toast(getApplicationContext());
        toast.setGravity(Gravity.CENTER_VERTICAL, 0, 0);
        toast.setDuration(Toast.LENGTH_LONG);
        toast.setView(layout);
        toast.show();
    }
}
